==> pyblackbirdbn-0.5.tar.gz: pyblackbirdbn-0.5/setup.py <==
#!/usr/bin/env python

import os
import sys

VERSION = '0.5'

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

license = """
MIT License

Copyright (c) 2018 koolsb

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

setup(name='pyblackbirdbn',
      version=VERSION,
      description='Python API for talking to Monoprice Blackbird 4k 8x8 HDBaseT Matrix',
      url='https://github.com/b3tts32/pyblackbird',
      download_url='https://github.com/b3tts32/pyblackbird/archive/{}.tar.gz'.format(VERSION),
      author='Rodney Betts',
      author_email='rodneybetts@gmail.com',
      license='MIT',
      install_requires=['pyserial>=3.4','pyserial-asyncio>=0.4'],
      packages=['pyblackbird'],
      classifiers=['Development Status :: 4 - Beta',
                   'Programming Language :: Python :: 3.5'],
      zip_safe=True)

==> pyblackbirdbn-0.6.tar.gz: pyblackbirdbn-0.6/setup.py <==
#!/usr/bin/env python

import os
import sys

VERSION = '0.6'

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

license = """
MIT License

Copyright (c) 2018 koolsb

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

setup(name='pyblackbirdbn',
      version=VERSION,
      description='Python API for talking to Monoprice Blackbird 4k 8x8 HDBaseT Matrix',
      url='https://github.com/b3tts32/pyblackbirdbn',
      download_url='https://github.com/b3tts32/pyblackbirdbn/archive/{}.tar.gz'.format(VERSION),
      author='Rodney Betts',
      author_email='rodneybetts@gmail.com',
      license='MIT',
      install_requires=['pyserial>=3.4','pyserial-asyncio>=0.4'],
      packages=['pyblackbirdbn'],
      classifiers=['Development Status :: 4 - Beta',
                   'Programming Language :: Python :: 3.5'],
      zip_safe=True)
